#include <SvgView.hh>

SvgView::SvgView(QWidget* parent):
	QGraphicsView(parent), parent(parent), svgItem(NULL)
{
	setScene(new QGraphicsScene(this));
	setTransformationAnchor(AnchorUnderMouse);
	setDragMode(ScrollHandDrag);
	setViewportUpdateMode(FullViewportUpdate);

	//Prepare the window
	setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
	setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
	setBackgroundBrush(QBrush(QColor(255, 255, 255)));
}

void SvgView::openFile(const QFile &file)
{
	if (!file.exists())
		return;

	QGraphicsScene *s = scene();

	s->clear();
	resetTransform();

	svgItem = new QGraphicsSvgItem(file.fileName(), dynamic_cast<QGraphicsItem*>(this));
	svgItem->setFlags(QGraphicsItem::ItemClipsToShape);
	svgItem->setCacheMode(QGraphicsItem::NoCache);
	svgItem->setZValue(0);

	centerOn(svgItem);
	fitInView(svgItem, Qt::KeepAspectRatio);

	s->addItem(svgItem);
	updateGeometry(); //Triggers the repaint/resize
}

void SvgView::clear()
{
	QGraphicsScene *s = scene();
	s->clear();
	resetTransform();
	updateGeometry();
}

void SvgView::paintEvent(QPaintEvent*)
{
	if (image.size() != viewport()->size()) {
		image = QImage(viewport()->size(), QImage::Format_ARGB32_Premultiplied);
	}

	QPainter imagePainter(&image);
	QGraphicsView::render(&imagePainter);
	imagePainter.end();

	QPainter p(viewport());
	p.drawImage(0, 0, image);
}

void SvgView::wheelEvent(QWheelEvent *event)
{
	qreal factor = qPow(1.2, event->delta() / 240.0);
	scale(factor, factor);
	event->accept();
}

void SvgView::resizeEvent(QResizeEvent *event)
{
	if(event->oldSize()==QSize(-1, -1)){
		//The window has just been created skip the part about resizing the image
	}else{
		qreal factorWidth = 1.0 + ((double)event->size().width() - (double)event->oldSize().width())/(double)event->oldSize().width();
		qreal factorHeight = 1.0 + ((double)event->size().height() - (double)event->oldSize().height())/(double)event->oldSize().height();
		if(factorWidth<factorHeight){
			scale(factorWidth, factorWidth);
		}else{
			scale(factorHeight, factorHeight);
		}
	}
	QWidget::resizeEvent(event);
	event->accept();
}
